@@ -11,10 +11,10 @@ class Job:
         - created_at: Timestamp of the creation of the batch.
         - updated_at: Timestamps of the last update of the batch.
         - batch_id: Id of the batch which the job belongs to.
-        - result: Result of the job.
         - errors: Error messages that occured while processing job.
         - id: Unique identifier for the batch
         - status: Status of the job
+        - result(optional): Result of the job.
         - variables (optional): dictionnary of variables of the job.
             None if the associated batch is non-parametrized
     """
@@ -23,8 +23,8 @@ class Job:
     batch_id: int
     id: int
     status: str
-    result: str
     created_at: str
     updated_at: str
     errors: List[str]
+    result: str = None
     variables: Dict = None
